@@ -1075,6 +1075,8 @@ class Witter():
         self.menuItemReplyTo = gtk.MenuItem("Reply To")
         urlmenu.append(self.menuItemReplyTo)
         self.menuItemReplyTo.show()
+	menuItemSeparator = gtk.SeparatorMenuItem()
+	urlmenu.append(menuItemSeparator)
         self.menuItemReTweet = gtk.MenuItem("ReTweet")
         urlmenu.append(self.menuItemReTweet)
 	self.menuItemReplyTo.connect("activate", self.replyTo)
